From: Sean Christopherson <seanjc@google.com>
To: Paolo Bonzini <pbonzini@redhat.com>,
Sean Christopherson <seanjc@google.com>,
Vitaly Kuznetsov <vkuznets@redhat.com>,
Jarkko Sakkinen <jarkko@kernel.org>
Cc: kvm@vger.kernel.org, linux-sgx@vger.kernel.org,
linux-kernel@vger.kernel.org,
Maxim Levitsky <mlevitsk@redhat.com>,
Hou Wenlong <houwenlong.hwl@antgroup.com>,
Xiaoyao Li <xiaoyao.li@intel.com>,
Kechen Lu <kechenl@nvidia.com>,
Oliver Upton <oliver.upton@linux.dev>,
Binbin Wu <binbin.wu@linux.intel.com>,
Yang Weijiang <weijiang.yang@intel.com>,
Robert Hoo <robert.hoo.linux@gmail.com>
Subject: [PATCH v3 23/57] KVM: x86: Rename kvm_cpu_cap_mask() to kvm_cpu_cap_init()
Date: Wed, 27 Nov 2024 17:33:50 -0800 [thread overview]
Message-ID: <20241128013424.4096668-24-seanjc@google.com> (raw)
In-Reply-To: <20241128013424.4096668-1-seanjc@google.com>
Rename kvm_cpu_cap_mask() to kvm_cpu_cap_init() in anticipation of merging
it with kvm_cpu_cap_init_kvm_defined(), and in anticipation of _setting_
bits in the helper (a future commit will play macro games to set emulated
feature flags via kvm_cpu_cap_init()).
No functional change intended.
Reviewed-by: Maxim Levitsky <mlevitsk@redhat.com>
Signed-off-by: Sean Christopherson <seanjc@google.com>
---
arch/x86/kvm/cpuid.c | 34 +++++++++++++++++-----------------
1 file changed, 17 insertions(+), 17 deletions(-)
diff --git a/arch/x86/kvm/cpuid.c b/arch/x86/kvm/cpuid.c
index 00b5b1a2a66f..9bd8bac3cd52 100644
--- a/arch/x86/kvm/cpuid.c
+++ b/arch/x86/kvm/cpuid.c
@@ -615,7 +615,7 @@ static __always_inline void __kvm_cpu_cap_mask(unsigned int leaf)
static __always_inline
void kvm_cpu_cap_init_kvm_defined(enum kvm_only_cpuid_leafs leaf, u32 mask)
{
/* Use kvm_cpu_cap_mask for leafs that aren't KVM-only. */
BUILD_BUG_ON(leaf < NCAPINTS);
kvm_cpu_caps[leaf] = mask;
@@ -623,7 +623,7 @@ void kvm_cpu_cap_init_kvm_defined(enum kvm_only_cpuid_leafs leaf, u32 mask)
__kvm_cpu_cap_mask(leaf);
}
-static __always_inline void kvm_cpu_cap_mask(enum cpuid_leafs leaf, u32 mask)
+static __always_inline void kvm_cpu_cap_init(enum cpuid_leafs leaf, u32 mask)
{
/* Use kvm_cpu_cap_init_kvm_defined for KVM-only leafs. */
BUILD_BUG_ON(leaf >= NCAPINTS);
@@ -661,7 +661,7 @@ void kvm_set_cpu_caps(void)
memcpy(&kvm_cpu_caps, &boot_cpu_data.x86_capability,
sizeof(kvm_cpu_caps) - (NKVMCAPINTS * sizeof(*kvm_cpu_caps)));
- kvm_cpu_cap_mask(CPUID_1_ECX,
+ kvm_cpu_cap_init(CPUID_1_ECX,
F(XMM3) |
F(PCLMULQDQ) |
0 /* DTES64 */ |
@@ -697,7 +697,7 @@ void kvm_set_cpu_caps(void)
/* KVM emulates x2apic in software irrespective of host support. */
kvm_cpu_cap_set(X86_FEATURE_X2APIC);
- kvm_cpu_cap_mask(CPUID_1_EDX,
+ kvm_cpu_cap_init(CPUID_1_EDX,
F(FPU) |
F(VME) |
F(DE) |
@@ -727,7 +727,7 @@ void kvm_set_cpu_caps(void)
0 /* HTT, TM, Reserved, PBE */
);
- kvm_cpu_cap_mask(CPUID_7_0_EBX,
+ kvm_cpu_cap_init(CPUID_7_0_EBX,
F(FSGSBASE) |
F(SGX) |
F(BMI1) |
@@ -757,7 +757,7 @@ void kvm_set_cpu_caps(void)
F(AVX512BW) |
F(AVX512VL));
- kvm_cpu_cap_mask(CPUID_7_ECX,
+ kvm_cpu_cap_init(CPUID_7_ECX,
F(AVX512VBMI) |
F(LA57) |
F(PKU) |
@@ -789,7 +789,7 @@ void kvm_set_cpu_caps(void)
if (!tdp_enabled || !boot_cpu_has(X86_FEATURE_OSPKE))
kvm_cpu_cap_clear(X86_FEATURE_PKU);
- kvm_cpu_cap_mask(CPUID_7_EDX,
+ kvm_cpu_cap_init(CPUID_7_EDX,
F(AVX512_4VNNIW) |
F(AVX512_4FMAPS) |
F(SPEC_CTRL) |
@@ -821,7 +821,7 @@ void kvm_set_cpu_caps(void)
if (boot_cpu_has(X86_FEATURE_AMD_SSBD))
kvm_cpu_cap_set(X86_FEATURE_SPEC_CTRL_SSBD);
- kvm_cpu_cap_mask(CPUID_7_1_EAX,
+ kvm_cpu_cap_init(CPUID_7_1_EAX,
F(SHA512) |
F(SM3) |
F(SM4) |
@@ -854,7 +854,7 @@ void kvm_set_cpu_caps(void)
F(MCDT_NO)
);
- kvm_cpu_cap_mask(CPUID_D_1_EAX,
+ kvm_cpu_cap_init(CPUID_D_1_EAX,
F(XSAVEOPT) |
F(XSAVEC) |
F(XGETBV1) |
@@ -874,7 +874,7 @@ void kvm_set_cpu_caps(void)
F(AVX10_512)
);
- kvm_cpu_cap_mask(CPUID_8000_0001_ECX,
+ kvm_cpu_cap_init(CPUID_8000_0001_ECX,
F(LAHF_LM) |
F(CMP_LEGACY) |
0 /*SVM*/ |
@@ -894,7 +894,7 @@ void kvm_set_cpu_caps(void)
0 /* PERFCTR_CORE */
);
- kvm_cpu_cap_mask(CPUID_8000_0001_EDX,
+ kvm_cpu_cap_init(CPUID_8000_0001_EDX,
F(FPU) |
F(VME) |
F(DE) |
@@ -935,7 +935,7 @@ void kvm_set_cpu_caps(void)
SF(CONSTANT_TSC)
);
- kvm_cpu_cap_mask(CPUID_8000_0008_EBX,
+ kvm_cpu_cap_init(CPUID_8000_0008_EBX,
F(CLZERO) |
F(XSAVEERPTR) |
F(WBNOINVD) |
@@ -981,9 +981,9 @@ void kvm_set_cpu_caps(void)
* Hide all SVM features by default, SVM will set the cap bits for
* features it emulates and/or exposes for L1.
*/
- kvm_cpu_cap_mask(CPUID_8000_000A_EDX, 0);
+ kvm_cpu_cap_init(CPUID_8000_000A_EDX, 0);
- kvm_cpu_cap_mask(CPUID_8000_001F_EAX,
+ kvm_cpu_cap_init(CPUID_8000_001F_EAX,
0 /* SME */ |
0 /* SEV */ |
0 /* VM_PAGE_FLUSH */ |
@@ -991,7 +991,7 @@ void kvm_set_cpu_caps(void)
F(SME_COHERENT)
);
- kvm_cpu_cap_mask(CPUID_8000_0021_EAX,
+ kvm_cpu_cap_init(CPUID_8000_0021_EAX,
F(NO_NESTED_DATA_BP) |
F(LFENCE_RDTSC) |
0 /* SmmPgCfgLock */ |
@@ -1015,7 +1015,7 @@ void kvm_set_cpu_caps(void)
* kernel. LFENCE_RDTSC was a Linux-defined synthetic feature long
* before AMD joined the bandwagon, e.g. LFENCE is serializing on most
* CPUs that support SSE2. On CPUs that don't support AMD's leaf,
* kvm_cpu_cap_mask() will unfortunately drop the flag due to ANDing
* the mask with the raw host CPUID, and reporting support in AMD's
* leaf can make it easier for userspace to detect the feature.
*/
@@ -1025,7 +1025,7 @@ void kvm_set_cpu_caps(void)
kvm_cpu_cap_set(X86_FEATURE_NULL_SEL_CLR_BASE);
kvm_cpu_cap_set(X86_FEATURE_NO_SMM_CTL_MSR);
- kvm_cpu_cap_mask(CPUID_C000_0001_EDX,
+ kvm_cpu_cap_init(CPUID_C000_0001_EDX,
F(XSTORE) |
F(XSTORE_EN) |
F(XCRYPT) |
@@ -615,7 +615,7 @@ static __always_inline void __kvm_cpu_cap_mask(unsigned int leaf)
void kvm_cpu_cap_init_kvm_defined(enum kvm_only_cpuid_leafs leaf, u32 mask)
{
- /* Use kvm_cpu_cap_mask for leafs that aren't KVM-only. */
+ /* Use kvm_cpu_cap_init for leafs that aren't KVM-only. */
BUILD_BUG_ON(leaf < NCAPINTS);
kvm_cpu_caps[leaf] = mask;
@@ -1015,7 +1015,7 @@ void kvm_set_cpu_caps(void)
* before AMD joined the bandwagon, e.g. LFENCE is serializing on most
* CPUs that support SSE2. On CPUs that don't support AMD's leaf,
- * kvm_cpu_cap_mask() will unfortunately drop the flag due to ANDing
+ * kvm_cpu_cap_init() will unfortunately drop the flag due to ANDing
* the mask with the raw host CPUID, and reporting support in AMD's
* leaf can make it easier for userspace to detect the feature.
--
2.47.0.338.g60cca15819-goog
next prev parent reply other threads:[~2024-11-28 1:35 UTC|newest]
Thread overview: 65+ messages / expand[flat|nested] mbox.gz Atom feed top
2024-11-28 1:33 [PATCH v3 00/57] KVM: x86: CPUID overhaul, fixes, and caching Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 01/57] KVM: x86: Use feature_bit() to clear CONSTANT_TSC when emulating CPUID Sean Christopherson
2024-12-13 10:53 ` Vitaly Kuznetsov
2024-11-28 1:33 ` [PATCH v3 02/57] KVM: x86: Limit use of F() and SF() to kvm_cpu_cap_{mask,init_kvm_defined}() Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 03/57] KVM: x86: Do all post-set CPUID processing during vCPU creation Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 04/57] KVM: x86: Explicitly do runtime CPUID updates "after" initial setup Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 05/57] KVM: x86: Account for KVM-reserved CR4 bits when passing through CR4 on VMX Sean Christopherson
2024-12-13 1:30 ` Chao Gao
2024-11-28 1:33 ` [PATCH v3 06/57] KVM: selftests: Update x86's set_sregs_test to match KVM's CPUID enforcement Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 07/57] KVM: selftests: Assert that vcpu->cpuid is non-NULL when getting CPUID entries Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 08/57] KVM: selftests: Refresh vCPU CPUID cache in __vcpu_get_cpuid_entry() Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 09/57] KVM: selftests: Verify KVM stuffs runtime CPUID OS bits on CR4 writes Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 10/57] KVM: x86: Move __kvm_is_valid_cr4() definition to x86.h Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 11/57] KVM: x86/pmu: Drop now-redundant refresh() during init() Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 12/57] KVM: x86: Drop now-redundant MAXPHYADDR and GPA rsvd bits from vCPU creation Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 13/57] KVM: x86: Disallow KVM_CAP_X86_DISABLE_EXITS after " Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 14/57] KVM: x86: Reject disabling of MWAIT/HLT interception when not allowed Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 15/57] KVM: x86: Drop the now unused KVM_X86_DISABLE_VALID_EXITS Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 16/57] KVM: selftests: Fix a bad TEST_REQUIRE() in x86's KVM PV test Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 17/57] KVM: selftests: Update x86's KVM PV test to match KVM's disabling exits behavior Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 18/57] KVM: x86: Zero out PV features cache when the CPUID leaf is not present Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 19/57] KVM: x86: Don't update PV features caches when enabling enforcement capability Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 20/57] KVM: x86: Do reverse CPUID sanity checks in __feature_leaf() Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 21/57] KVM: x86: Account for max supported CPUID leaf when getting raw host CPUID Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 22/57] KVM: x86: Unpack F() CPUID feature flag macros to one flag per line of code Sean Christopherson
2024-11-28 1:33 ` Sean Christopherson [this message]
2024-11-28 1:33 ` [PATCH v3 24/57] KVM: x86: Add a macro to init CPUID features that are 64-bit only Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 25/57] KVM: x86: Add a macro to precisely handle aliased 0x1.EDX CPUID features Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 26/57] KVM: x86: Handle kernel- and KVM-defined CPUID words in a single helper Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 27/57] KVM: x86: #undef SPEC_CTRL_SSBD in cpuid.c to avoid macro collisions Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 28/57] KVM: x86: Harden CPU capabilities processing against out-of-scope features Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 29/57] KVM: x86: Add a macro to init CPUID features that ignore host kernel support Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 30/57] KVM: x86: Add a macro to init CPUID features that KVM emulates in software Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 31/57] KVM: x86: Swap incoming guest CPUID into vCPU before massaging in KVM_SET_CPUID2 Sean Christopherson
2024-11-28 1:33 ` [PATCH v3 32/57] KVM: x86: Clear PV_UNHALT for !HLT-exiting only when userspace sets CPUID Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 33/57] KVM: x86: Remove unnecessary caching of KVM's PV CPUID base Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 34/57] KVM: x86: Always operate on kvm_vcpu data in cpuid_entry2_find() Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 35/57] KVM: x86: Move kvm_find_cpuid_entry{,_index}() up near cpuid_entry2_find() Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 36/57] KVM: x86: Remove all direct usage of cpuid_entry2_find() Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 37/57] KVM: x86: Advertise TSC_DEADLINE_TIMER in KVM_GET_SUPPORTED_CPUID Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 38/57] KVM: x86: Advertise HYPERVISOR " Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 39/57] KVM: x86: Rename "governed features" helpers to use "guest_cpu_cap" Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 40/57] KVM: x86: Replace guts of "governed" features with comprehensive cpu_caps Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 41/57] KVM: x86: Initialize guest cpu_caps based on guest CPUID Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 42/57] KVM: x86: Extract code for generating per-entry emulated CPUID information Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 43/57] KVM: x86: Treat MONTIOR/MWAIT as a "partially emulated" feature Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 44/57] KVM: x86: Initialize guest cpu_caps based on KVM support Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 45/57] KVM: x86: Avoid double CPUID lookup when updating MWAIT at runtime Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 46/57] KVM: x86: Drop unnecessary check that cpuid_entry2_find() returns right leaf Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 47/57] KVM: x86: Update OS{XSAVE,PKE} bits in guest CPUID irrespective of host support Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 48/57] KVM: x86: Update guest cpu_caps at runtime for dynamic CPUID-based features Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 49/57] KVM: x86: Shuffle code to prepare for dropping guest_cpuid_has() Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 50/57] KVM: x86: Replace (almost) all guest CPUID feature queries with cpu_caps Sean Christopherson
2024-12-13 2:14 ` Chao Gao
2024-12-17 0:05 ` Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 51/57] KVM: x86: Drop superfluous host XSAVE check when adjusting guest XSAVES caps Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 52/57] KVM: x86: Add a macro for features that are synthesized into boot_cpu_data Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 53/57] KVM: x86: Pull CPUID capabilities from boot_cpu_data only as needed Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 54/57] KVM: x86: Rename "SF" macro to "SCATTERED_F" Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 55/57] KVM: x86: Explicitly track feature flags that require vendor enabling Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 56/57] KVM: x86: Explicitly track feature flags that are enabled at runtime Sean Christopherson
2024-11-28 1:34 ` [PATCH v3 57/57] KVM: x86: Use only local variables (no bitmask) to init kvm_cpu_caps Sean Christopherson
2024-12-18 1:15 ` Maxim Levitsky
2024-12-18 1:13 ` [PATCH v3 00/57] KVM: x86: CPUID overhaul, fixes, and caching Maxim Levitsky
2024-12-19 2:40 ` Sean Christopherson
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20241128013424.4096668-24-seanjc@google.com \
--to=seanjc@google.com \
--cc=binbin.wu@linux.intel.com \
--cc=houwenlong.hwl@antgroup.com \
--cc=jarkko@kernel.org \
--cc=kechenl@nvidia.com \
--cc=kvm@vger.kernel.org \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-sgx@vger.kernel.org \
--cc=mlevitsk@redhat.com \
--cc=oliver.upton@linux.dev \
--cc=pbonzini@redhat.com \
--cc=robert.hoo.linux@gmail.com \
--cc=vkuznets@redhat.com \
--cc=weijiang.yang@intel.com \
--cc=xiaoyao.li@intel.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox